@@ -324,10 +324,11 @@ void cthd_sysfs_cdev_rapl::set_tcc(int tcc) {
 	if (!sysfs.exists("tcc_offset_degree_celsius"))
 		return;
 
-	sysfs.write("tcc_offset_degree_celsius", tcc);
+	if (sysfs.write("tcc_offset_degree_celsius", tcc) == -1)
+		thd_log_debug("TCC write failed\n");
 }
 
-void cthd_sysfs_cdev_rapl::set_adaptive_target(struct adaptive_target target) {
+void cthd_sysfs_cdev_rapl::set_adaptive_target(struct adaptive_target &target) {
 	int argument = std::stoi(target.argument, NULL);
 	if (target.code == "PL1MAX") {
 		int pl1_rapl;
@@ -495,12 +496,12 @@ bool cthd_sysfs_cdev_rapl::read_ppcc_power_limits() {
 		}
 
 		if (pl0_max_pwr <= pl0_min_pwr) {
-			thd_log_info("Invalid limits: ppcc limits max:%u min:%u  min_win:%u step:%u\n",
+			thd_log_info("Invalid limits: ppcc limits max:%d min:%d  min_win:%d step:%d\n",
 					pl0_max_pwr, pl0_min_pwr, pl0_min_window, pl0_step_pwr);
 			return false;
 		}
 
-		thd_log_info("ppcc limits max:%u min:%u  min_win:%u step:%u\n",
+		thd_log_info("ppcc limits max:%d min:%d  min_win:%d step:%d\n",
 				pl0_max_pwr, pl0_min_pwr, pl0_min_window, pl0_step_pwr);
 
 		int policy_matched;
@@ -570,12 +571,12 @@ bool cthd_sysfs_cdev_rapl::read_ppcc_power_limits() {
 		int def_max_power;
 
 		if (pl0_max_pwr <= pl0_min_pwr) {
-			thd_log_info("Invalid limits: ppcc limits max:%u min:%u  min_win:%u step:%u\n",
+			thd_log_info("Invalid limits: ppcc limits max:%d min:%d  min_win:%d step:%d\n",
 					pl0_max_pwr, pl0_min_pwr, pl0_min_window, pl0_step_pwr);
 			return false;
 		}
 
-		thd_log_info("ppcc limits max:%u min:%u  min_win:%u step:%u\n",
+		thd_log_info("ppcc limits max:%d min:%d  min_win:%d step:%d\n",
 				pl0_max_pwr, pl0_min_pwr, pl0_min_window, pl0_step_pwr);
 
 		def_max_power = rapl_read_pl1_max();
