@@ -131,7 +131,9 @@ gboolean thd_dbus_interface_disable_cooling_device(PrefObject *obj, gchar *name,
 }
 
 // This is a generated file, which expects the above prototypes
+#ifndef GDBUS
 #include "thd_dbus_interface.h"
+#endif
 
 // DBUS Related functions
 
@@ -144,8 +146,10 @@ static void pref_object_init(PrefObject *obj) {
 static void pref_object_class_init(PrefObjectClass *_class) {
 	g_assert(_class != NULL);
 
+#ifndef GDBUS
 	dbus_g_object_type_install_info(PREF_TYPE_OBJECT,
 			&dbus_glib_thd_dbus_interface_object_info);
+#endif
 }
 
 // Callback function called to inform a sent value via dbus
@@ -584,7 +588,7 @@ gboolean thd_dbus_interface_get_sensor_temperature(PrefObject *obj, int index,
 #pragma GCC diagnostic push
 
 static GDBusInterfaceVTable interface_vtable;
-extern gint watcher_id;
+extern gint own_id;
 
 static GDBusNodeInfo *
 thd_dbus_load_introspection(const gchar *filename, GError **error)
@@ -1220,18 +1224,20 @@ int thd_dbus_server_init(gboolean (*exit_handler)(void)) {
 		return THD_FATAL_ERROR;
 	}
 
+	thd_dbus_exit_callback = exit_handler;
+
 	interface_vtable.method_call = thd_dbus_handle_method_call;
 	interface_vtable.get_property = thd_dbus_handle_get_property;
 	interface_vtable.set_property = thd_dbus_handle_set_property;
 
-	watcher_id = g_bus_own_name(G_BUS_TYPE_SYSTEM,
-				    "org.freedesktop.thermald",
-				    G_BUS_NAME_OWNER_FLAGS_REPLACE,
-				    thd_dbus_on_bus_acquired,
-				    thd_dbus_on_name_acquired,
-				    thd_dbus_on_name_lost,
-				    g_object_ref(value_obj),
-				    NULL);
+	own_id = g_bus_own_name(G_BUS_TYPE_SYSTEM,
+				"org.freedesktop.thermald",
+				G_BUS_NAME_OWNER_FLAGS_REPLACE,
+				thd_dbus_on_bus_acquired,
+				thd_dbus_on_name_acquired,
+				thd_dbus_on_name_lost,
+				g_object_ref(value_obj),
+				NULL);
 	
 	return THD_SUCCESS;
 }
