@@ -48,7 +48,7 @@ static void *cthd_engine_thread(void *arg);
 
 cthd_engine::cthd_engine(std::string _uuid) :
 		current_cdev_index(0), current_zone_index(0), current_sensor_index(0), parse_thermal_zone_success(
-				false), parse_thermal_cdev_success(false), uuid(_uuid), parser_disabled(
+				false), parse_thermal_cdev_success(false), uuid(std::move(_uuid)), parser_disabled(
 				false), adaptive_mode(false), poll_timeout_msec(-1), wakeup_fd(
 				-1), uevent_fd(-1), control_mode(COMPLEMENTRY), write_pipe_fd(
 				0), preference(0), status(true), thz_last_uevent_time(0), thz_last_temp_ind_time(
@@ -716,6 +716,10 @@ static supported_ids_t id_table[] = {
 		{ 6, 0xbe }, // Alderlake N
 		{ 6, 0xbf }, // Raptorlake S
 		{ 6, 0xaa }, // Mateor Lake L
+		{ 6, 0xbd }, // Lunar Lake M
+		{ 6, 0xc6 }, // Arrow Lake
+		{ 6, 0xc5 }, // Arrow Lake H
+		{ 6, 0xb5 }, // Arrow Lake U
 		{ 0, 0 } // Last Invalid entry
 };
 
@@ -894,7 +898,7 @@ void cthd_engine::thd_read_default_cooling_devices() {
 }
 
 ppcc_t* cthd_engine::get_ppcc_param(std::string name) {
-	return parser.get_ppcc_param(name);
+	return parser.get_ppcc_param(std::move(name));
 }
 
 cthd_zone* cthd_engine::search_zone(std::string name) {
@@ -1030,7 +1034,7 @@ int cthd_engine::user_add_sensor(std::string name, std::string path) {
 			return THD_SUCCESS;
 		}
 	}
-	sensor = new cthd_sensor(current_sensor_index, path, name, SENSOR_TYPE_RAW);
+	sensor = new cthd_sensor(current_sensor_index, std::move(path), std::move(name), SENSOR_TYPE_RAW);
 	if (sensor->sensor_update() != THD_SUCCESS) {
 		delete sensor;
 		pthread_mutex_unlock(&thd_engine_mutex);
@@ -1070,8 +1074,8 @@ int cthd_engine::user_add_virtual_sensor(std::string name,
 	}
 	cthd_sensor_virtual *virt_sensor;
 
-	virt_sensor = new cthd_sensor_virtual(current_sensor_index, name,
-			dep_sensor, slope, intercept);
+	virt_sensor = new cthd_sensor_virtual(current_sensor_index, std::move(name),
+			std::move(dep_sensor), slope, intercept);
 	if (virt_sensor->sensor_update() != THD_SUCCESS) {
 		delete virt_sensor;
 		pthread_mutex_unlock(&thd_engine_mutex);
@@ -1113,7 +1117,7 @@ int cthd_engine::user_set_psv_temp(std::string name, unsigned int temp) {
 	int ret;
 
 	pthread_mutex_lock(&thd_engine_mutex);
-	zone = get_zone(name);
+	zone = get_zone(std::move(name));
 	if (!zone) {
 		pthread_mutex_unlock(&thd_engine_mutex);
 		thd_log_warn("user_set_psv_temp\n");
@@ -1131,7 +1135,7 @@ int cthd_engine::user_set_max_temp(std::string name, unsigned int temp) {
 	int ret;
 
 	pthread_mutex_lock(&thd_engine_mutex);
-	zone = get_zone(name);
+	zone = get_zone(std::move(name));
 	if (!zone) {
 		pthread_mutex_unlock(&thd_engine_mutex);
 		thd_log_warn("user_set_max_temp\n");
@@ -1149,7 +1153,7 @@ int cthd_engine::user_add_zone(std::string zone_name, unsigned int trip_temp,
 	int ret = THD_SUCCESS;
 
 	cthd_zone_dynamic *zone = new cthd_zone_dynamic(current_zone_index,
-			zone_name, trip_temp, PASSIVE, sensor_name, cdev_name);
+			std::move(zone_name), trip_temp, PASSIVE, std::move(sensor_name), std::move(cdev_name));
 	if (!zone) {
 		return THD_ERROR;
 	}
@@ -1175,7 +1179,7 @@ int cthd_engine::user_set_zone_status(std::string name, int status) {
 	cthd_zone *zone;
 
 	pthread_mutex_lock(&thd_engine_mutex);
-	zone = get_zone(name);
+	zone = get_zone(std::move(name));
 	if (!zone) {
 		pthread_mutex_unlock(&thd_engine_mutex);
 		return THD_ERROR;
@@ -1196,7 +1200,7 @@ int cthd_engine::user_get_zone_status(std::string name, int *status) {
 	cthd_zone *zone;
 
 	pthread_mutex_lock(&thd_engine_mutex);
-	zone = get_zone(name);
+	zone = get_zone(std::move(name));
 	if (!zone) {
 		pthread_mutex_unlock(&thd_engine_mutex);
 		return THD_ERROR;
@@ -1240,12 +1244,12 @@ int cthd_engine::user_add_cdev(std::string cdev_name, std::string cdev_path,
 	if (!cdev) {
 		cthd_gen_sysfs_cdev *cdev_sysfs;
 
-		cdev_sysfs = new cthd_gen_sysfs_cdev(current_cdev_index, cdev_path);
+		cdev_sysfs = new cthd_gen_sysfs_cdev(current_cdev_index, std::move(cdev_path));
 		if (!cdev_sysfs) {
 			pthread_mutex_unlock(&thd_engine_mutex);
 			return THD_ERROR;
 		}
-		cdev_sysfs->set_cdev_type(cdev_name);
+		cdev_sysfs->set_cdev_type(std::move(cdev_name));
 		if (cdev_sysfs->update() != THD_SUCCESS) {
 			delete cdev_sysfs;
 			pthread_mutex_unlock(&thd_engine_mutex);
