@@ -37,20 +37,9 @@
 #include "thd_sensor_virtual.h"
 #include "thd_cdev_backlight.h"
 #include "thd_int3400.h"
-#include "thd_sensor_kbl_amdgpu_thermal.h"
-#include "thd_sensor_kbl_amdgpu_power.h"
-#include "thd_cdev_kbl_amdgpu.h"
-#include "thd_zone_kbl_amdgpu.h"
-#include "thd_sensor_kbl_g_mcp.h"
-#include "thd_zone_kbl_g_mcp.h"
-#include "thd_cdev_kbl_amdgpu.h"
-#include "thd_zone_kbl_g_mcp.h"
 #include "thd_sensor_rapl_power.h"
 #include "thd_zone_rapl_power.h"
 
-#ifdef GLIB_SUPPORT
-#include "thd_cdev_modem.h"
-#endif
 
 // Default CPU cooling devices, which are not part of thermal sysfs
 // Since non trivial initialization is not supported, we init all fields even if they are not needed
@@ -181,30 +170,6 @@ int cthd_engine_default::read_thermal_sensors() {
 		thd_log_warn("Thermal DTS: No coretemp sysfs found\n");
 	}
 
-	cthd_sensor_kbl_amdgpu_thermal *amdgpu_thermal = new cthd_sensor_kbl_amdgpu_thermal(index);
-	if (amdgpu_thermal->sensor_update() == THD_SUCCESS) {
-		sensors.push_back(amdgpu_thermal);
-		++index;
-	} else {
-		delete amdgpu_thermal;
-	}
-
-	cthd_sensor_kbl_amdgpu_power *amdgpu_power = new cthd_sensor_kbl_amdgpu_power(index);
-	if (amdgpu_power->sensor_update() == THD_SUCCESS) {
-		sensors.push_back(amdgpu_power);
-		++index;
-	} else {
-		delete amdgpu_power;
-	}
-
-	cthd_sensor_kbl_g_mcp *mcp_power = new cthd_sensor_kbl_g_mcp(index);
-	if (mcp_power->sensor_update() == THD_SUCCESS) {
-		sensors.push_back(mcp_power);
-		++index;
-	} else {
-		delete mcp_power;
-	}
-
 	if (debug_mode_on()) {
 		// Only used for debug power using ThermalMonitor
 		cthd_sensor_rapl_power *rapl_power = new cthd_sensor_rapl_power(index);
@@ -313,7 +278,7 @@ bool cthd_engine_default::add_int340x_processor_dev(void)
 
 				thd_log_info("Processor thermal device is present \n");
 				thd_log_info("It will act as CPU thermal zone !! \n");
-				thd_log_info("Processor thermal device passive Trip is %d\n",
+				thd_log_info("Processor thermal device passive Trip is %u\n",
 						trip->get_trip_temp());
 
 				processor_thermal->set_zone_active();
@@ -622,18 +587,7 @@ int cthd_engine_default::add_replace_cdev(cooling_dev_t *config) {
 	}
 	if (!cdev_present) {
 		// create new
-		if (config->type_string.compare("intel_modem") == 0) {
-#ifdef GLIB_SUPPORT
-			/*
-			 * Add Modem as cdev
-			 * intel_modem is a modem identifier across all intel platforms.
-			 * The differences between the modems of various intel platforms
-			 * are to be taken care in the cdev implementation.
-			 */
-			cdev = new cthd_cdev_modem(current_cdev_index, config->path_str);
-#endif
-		} else
-			cdev = new cthd_gen_sysfs_cdev(current_cdev_index, config->path_str);
+		cdev = new cthd_gen_sysfs_cdev(current_cdev_index, config->path_str);
 		if (!cdev)
 			return THD_ERROR;
 		cdev->set_cdev_type(config->type_string);
@@ -788,18 +742,6 @@ int cthd_engine_default::read_cooling_devices() {
 			delete backlight_dev;
 	}
 
-	cthd_cdev *cdev_amdgpu = search_cdev("amdgpu");
-	if (!cdev_amdgpu) {
-		cthd_cdev_kgl_amdgpu *cdev_amdgpu = new cthd_cdev_kgl_amdgpu(
-				current_cdev_index, 0);
-		cdev_amdgpu->set_cdev_type("amdgpu");
-		if (cdev_amdgpu->update() == THD_SUCCESS) {
-			cdevs.push_back(cdev_amdgpu);
-			++current_cdev_index;
-		} else
-			delete cdev_amdgpu;
-	}
-
 	// Add from XML cooling device config
 	if (!parser_init() && parser.platform_matched()) {
 		for (int i = 0; i < parser.cdev_count(); ++i) {
