@@ -34,6 +34,11 @@
 #include "thd_engine.h"
 #include "thd_trt_art_reader.h"
 
+#define DECI_KELVIN_TO_CELSIUS(t)       ({                      \
+        int _t = (t);                                          \
+        ((_t-2732 >= 0) ? (_t-2732+5)/10 : (_t-2732-5)/10);     \
+})
+
 enum adaptive_condition {
 	Default = 0x01,
 	Orientation,
@@ -123,10 +128,10 @@ struct condition {
 	int argument;
 	enum adaptive_operation operation;
 	enum adaptive_comparison time_comparison;
-	int time;
+	time_t time;
 	int target;
 	int state;
-	int state_entry_time;
+	time_t state_entry_time;
 	int ignore_condition;
 };
 
